4.39. umbra.ui.completers — Umbra 1.0.9 documentation

# 4.39. umbra.ui.completers

completers.py

Platform:
  Windows, Linux, Mac Os X.
Description:
  Defines the Application completers classes.
  Each completer class completion list is initialized only once per session and
  cached at the first class instantiation.

Others:

## 4.39.1. Module Attributes

`umbra.ui.completers.` `LOGGER`

## 4.39.2. Classes

class `umbra.ui.completers.` `DefaultCompleter`(parent=None, language=None, tokens=None)

  Bases: `PyQt4.QtGui.QCompleter`

  Defines a QCompleter subclass used as a completion widget.

  Initializes the class.

  Parameters: | parent (QObject) – Object parent. language (unicode) – Language name. tokens (tuple or list) – Completer tokens list.

  `language`

    Property for self.__language attribute.

    Returns: | self.__language.
    Return type: | unicode

  `updateModel`(words)

    Updates the completer model.

    Parameters: | words (tuple or list) – Words to update the completer with.
    Returns: | Method success.
    Return type: | bool